docs.rs failed to build everything-ipc-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
everything-ipc-0.1.2
everything-ipc
Rust port of voidtools' Everything's IPC SDK. Can be used to search user files quickly.
Features
- Support both Everything v1.4 and v1.5, including Alpha version.
- Higher performance than Everything v1.4's official SDK:
- Hot query time is about 30% shorter.
- Sending blocking time is 60% shorter for async queries.
- Support both sync and async (Tokio) querying.
- Search text generating utilities.
- Folder-based batch IPC and cache.
See documentation for details.
Usage
// cargo add everything-ipc
use ;
let everything = new.expect;
let list = everything
.query_wait
.request_flags
.sort
.max_results
.call
.expect;
println!;
println!;
for item in list.iter
println!;
/*
Found 5 items:
Filename Size Path
MRT.exe 223939376 C:\Windows\System32
MRT-KB890830.exe 133315992 C:\Windows\System32
OneDriveSetup.exe 89771848 C:\Windows\WinSxS\amd64_microsoft-windows-onedrive-setup_31bf3856ad364e35_10.0.26100.5074_none_c1340e9ad5f0a5d0
OneDriveSetup.exe 89771848 C:\Windows\System32
OneDriveSetup.exe 60357040 C:\Windows\WinSxS\amd64_microsoft-windows-onedrive-setup_31bf3856ad364e35_10.0.26100.1_none_2233e98c8e9ce5f5
Total: 5742 items
*/