Module pipe

Module pipe 

Available on crate feature tokio only.
Everything’s named pipe IPC interface, supported by Everything v1.5+.

Compared to the wm IPC interface, this new pipe interface isn’t quite great. So currently only get_folder_size() is implemented. If the need arises, other features can be added.

Everything 1.5 SDK - voidtools forum

TODO: Batch IPC

Structs

EverythingClient
Client structure for IPC communication
EverythingClientBuilder
Use builder syntax to set the inputs and finish with build().
Message
Message header for IPC communication

Enums

IpcError
Error type for Everything IPC operations