EverythingClientBuilder

Struct EverythingClientBuilder 

pub struct EverythingClientBuilder<'f1, S: State = Empty> { /* private fields */ }
Available on crate feature tokio only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'f1, S: State> EverythingClientBuilder<'f1, S>

pub async fn build(self) -> Result<EverythingClient, IpcError>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn instance_name( self, value: &'f1 str, ) -> EverythingClientBuilder<'f1, SetInstanceName<S>>
where S::InstanceName: IsUnset,

Optional (Some / Option setters).

pub fn maybe_instance_name( self, value: Option<&'f1 str>, ) -> EverythingClientBuilder<'f1, SetInstanceName<S>>
where S::InstanceName: IsUnset,

Optional (Some / Option setters).

pub fn timeout( self, value: Duration, ) -> EverythingClientBuilder<'f1, SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

Automatic retry until timeout if the pipe is busy.

pub fn maybe_timeout( self, value: Option<Duration>, ) -> EverythingClientBuilder<'f1, SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters). Default: Duration::from_secs(10).

Automatic retry until timeout if the pipe is busy.