Available on crate feature
folder only.Expand description
Folder size batch lookup and cache.
- Batch lookup of all folder sizes in the parent folder.
- Thread-local cache with
get_folder_size(). - For drivers (like
C:\), it uses Windows API directly.
References
Structs
- Folder
Size Client - Folder size client with parent directory cache.
- Folder
Size Client GetFolder Size Builder - Use builder syntax to set the inputs and finish with
call(). - GetFolder
Size Builder - Use builder syntax to set the inputs and finish with
call().
Enums
Functions
- get_
folder_ size - Get the size of a folder.