Module size

Module size 

Available on crate feature folder only.
Folder size batch lookup and cache.

  • Batch lookup of all folder sizes in the parent folder.
  • Thread-local cache.
  • For drivers (like C:\), it uses Windows API directly.

References

Structs

GetFolderSizeBuilder
Use builder syntax to set the inputs and finish with call().

Enums

Error

Functions

get_folder_size
Get the size of a folder.