Available on crate feature
folder only.Expand description
Folder size batch lookup and cache.
- Batch lookup of all folder sizes in the parent folder.
- Thread-local cache.
- For drivers (like
C:\), it uses Windows API directly.
References
Structs
- GetFolder
Size Builder - Use builder syntax to set the inputs and finish with
call().
Enums
Functions
- get_
folder_ size - Get the size of a folder.