pub struct FolderSizeClient { /* private fields */ }Available on crate feature
folder only.Expand description
Folder size client with parent directory cache.
Implementations
Sourceimpl FolderSizeClient
impl FolderSizeClient
pub const fn new() -> Self
Sourcepub fn get_folder_size<'f1, 'f2, 'f3>(
&'f1 mut self,
path: &'f2 Path,
) -> FolderSizeClientGetFolderSizeBuilder<'f1, 'f2, 'f3>
pub fn get_folder_size<'f1, 'f2, 'f3>( &'f1 mut self, path: &'f2 Path, ) -> FolderSizeClientGetFolderSizeBuilder<'f1, 'f2, 'f3>
Get the size of a folder.
See folder::size for details.
Arguments
-
path: An absolute path to a folder -
timeout: Optional timeout for IPC queries. IfNone, uses the default timeout. -
parent_max_size: Optional mutable reference to receive the maximum size of folders in the parent folder.You may also want to set
eager_get_links. -
eager_get_links: Iftrue, for folders in the parent folder with size 0, eagerly resolve symlinks/junctions and query the resolved path’s size.
Returns
Ok(u64): The size in bytesErr(Error): If the path is invalid