Available on crate feature
tokio only.Expand description
Everything’s named pipe IPC interface, supported by Everything v1.5+.
Compared to the wm IPC interface, this new pipe interface isn’t quite great.
So currently only get_folder_size() is implemented.
If the need arises, other features can be added.
Everything 1.5 SDK - voidtools forum
TODO: Batch IPC
Structs
- Everything
Client - Client structure for IPC communication
- Everything
Client Builder - Use builder syntax to set the inputs and finish with
build(). - Message
- Message header for IPC communication
Enums
- IpcError
- Error type for Everything IPC operations