pub struct EverythingClient { /* private fields */ }Available on crate feature
tokio only.Expand description
Client structure for IPC communication
There can only be one client, you should drop this as early as possible.
See pipe for details.
Implementations
Sourceimpl EverythingClient
impl EverythingClient
Sourcepub fn try_new(instance_name: Option<&str>) -> Result<Self, IpcError>
pub fn try_new(instance_name: Option<&str>) -> Result<Self, IpcError>
Connect to the Everything IPC pipe
instance_name can be None or empty to connect to the unnamed instance.
Sourcepub fn builder<'f1>() -> EverythingClientBuilder<'f1>
pub fn builder<'f1>() -> EverythingClientBuilder<'f1>
Connect to the Everything IPC pipe, trying common instance names.
This will first try to connect without an instance name (default), and if that fails, try “1.5a”.
Sourceimpl EverythingClient
impl EverythingClient
Sourcepub fn get_folder_size(&self, path: &str) -> Result<u64, IpcError>
pub fn get_folder_size(&self, path: &str) -> Result<u64, IpcError>
Retrieves the indexed folder size.
Remarks
Everything 1.5 will index folder sizes by default. This can be disabled under Tools -> Options -> Indexes -> Index folder sizes.
A case sensensitive search is performed first. If no folder is found a case insensitive search is performed.