pub fn normalize_path_ev<'a>(path: &'a Path) -> Cow<'a, Path>Expand description
Convert a path into the form can be recognized by Everything.
Basically removes the verbatim prefix, e.g. \\?\C:\Windows -> C:\Windows.
Note that this does not resolve symbolic links and junctions,
for which you can call canonicalize_path_ev().
https://github.com/dylni/normpath can also be used, but a bit overkill.